/*
 * This file is part of jSpeed.
 *
 * jSpeed is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * jSpeed is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with jSpeed.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <QtCore/QString>
#include <QtCore/QDebug>
#include <QtGui/QGraphicsBlurEffect>
#include <QtGui/QGraphicsItem>
#include "blureffect.h"

namespace
{
    Effect::AttributeDetails ATTRIBUTES[BlurEffect::ATTRIBUTE_COUNT] =
    {
     {"radius", true}
    };
}

BlurEffect::BlurEffect(): Effect()
{
    effect_ = new QGraphicsBlurEffect;
}

bool BlurEffect::setAttribute(QString const& name, QString const& value)
{
    qreal realVal = 0;
    int attrId = -1;

    if((attrId = getAttribute(name, value, ATTRIBUTES, ATTRIBUTE_COUNT, realVal)) != -1)
    {
        Attribute attr = static_cast<Attribute>(attrId);

        switch(attr)
        {
        case RADIUS:
            effect_->setBlurRadius(realVal);
            break;
        default:
            qDebug() << "Unknown attribute: " << attr;
            return false;
        }

        return true;
    }
    else
    {
        return false;
    }
}

void BlurEffect::apply(QGraphicsItem* item)
{
    item->setGraphicsEffect(effect_);
}
